#  Secure Plugin remover for macOS
![Image1](https://raw.githubusercontent.com/thy2134/MacSAFER/master/images/run-1.png)

## Description
This program removes any known malicious secure plugins installed from Korean E-Commerce, Government, Internet Banking websites. As those programs consume lots of resources on your mac, removing these will result in a notifiable performance enhancement.    
This program is simillar to ["구라제거기"](http://teus.me/427) which works on Windows systems.
## Requirements
- Python 3

## Installation 
- Using PyPI 
    1. Install by `pip3 install macsafer`.
    2. Start by `macsafer`.

## Usage
- User password is required, since most plugins require root permissions to uninstall the program.
- Type user password when prompted. This program automatically finds and tries to remove all known plugins.
- Follow instructions on windows appeared to remove applications.
- You're all done. To verify if it's completely deleted, re-run this program. 